'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _reactIntl = require('react-intl');

var _immutable = require('immutable');

var _immutable2 = _interopRequireDefault(_immutable);

var _cspaceLayout = require('cspace-layout');

var _CancelButton = require('../navigation/CancelButton');

var _CancelButton2 = _interopRequireDefault(_CancelButton);

var _RunButton = require('../record/RunButton');

var _RunButton2 = _interopRequireDefault(_RunButton);

var _RunBatchButton = require('../../../styles/cspace-ui/RunBatchButton.css');

var _RunBatchButton2 = _interopRequireDefault(_RunBatchButton);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const messages = (0, _reactIntl.defineMessages)({
  prompt: {
    'id': 'batchModal.prompt',
    'defaultMessage': 'Run this batch job?'
  },
  cancel: {
    'id': 'batchModal.cancel',
    'defaultMessage': 'Cancel'
  },
  run: {
    'id': 'batchModal.run',
    'defaultMessage': 'Run'
  }
});

const propTypes = {
  isOpen: _propTypes2.default.bool,
  isRunning: _propTypes2.default.bool,
  batchItem: _propTypes2.default.instanceOf(_immutable2.default.Map),
  onCancelButtonClick: _propTypes2.default.func,
  onCloseButtonClick: _propTypes2.default.func,
  onRunButtonClick: _propTypes2.default.func
};

class BatchModal extends _react.Component {
  constructor() {
    super();

    this.renderButtonBar = this.renderButtonBar.bind(this);
  }

  renderButtonBar() {
    var _props = this.props;
    const isRunning = _props.isRunning,
          onCancelButtonClick = _props.onCancelButtonClick,
          onRunButtonClick = _props.onRunButtonClick;


    return _react2.default.createElement(
      'div',
      null,
      _react2.default.createElement(_CancelButton2.default, {
        disabled: isRunning,
        label: _react2.default.createElement(_reactIntl.FormattedMessage, messages.cancel),
        onClick: onCancelButtonClick
      }),
      _react2.default.createElement(_RunButton2.default, {
        className: _RunBatchButton2.default.common,
        isRunning: isRunning,
        label: _react2.default.createElement(_reactIntl.FormattedMessage, messages.run),
        onClick: onRunButtonClick
      })
    );
  }

  render() {
    var _props2 = this.props;
    const isOpen = _props2.isOpen,
          batchItem = _props2.batchItem,
          onCloseButtonClick = _props2.onCloseButtonClick;


    if (!isOpen || !batchItem) {
      return null;
    }

    return _react2.default.createElement(
      _cspaceLayout.Modal,
      {
        isOpen: isOpen,
        title: _react2.default.createElement(
          'h1',
          null,
          batchItem.get('name')
        ),
        closeButtonClassName: 'material-icons',
        closeButtonLabel: 'close',
        renderButtonBar: this.renderButtonBar,
        onCloseButtonClick: onCloseButtonClick
      },
      _react2.default.createElement(_reactIntl.FormattedMessage, messages.prompt)
    );
  }
}

exports.default = BatchModal;
BatchModal.modalName = 'BatchModal';
BatchModal.propTypes = propTypes;