'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _reactIntl = require('react-intl');

var _immutable = require('immutable');

var _immutable2 = _interopRequireDefault(_immutable);

var _cspaceLayout = require('cspace-layout');

var _CancelButton = require('../navigation/CancelButton');

var _CancelButton2 = _interopRequireDefault(_CancelButton);

var _UnrelateButton = require('../record/UnrelateButton');

var _UnrelateButton2 = _interopRequireDefault(_UnrelateButton);

var _ConfirmRecordUnrelateModal = require('../../../styles/cspace-ui/ConfirmRecordUnrelateModal.css');

var _ConfirmRecordUnrelateModal2 = _interopRequireDefault(_ConfirmRecordUnrelateModal);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const messages = (0, _reactIntl.defineMessages)({
  title: {
    'id': 'confirmRecordUnrelateModal.title',
    'defaultMessage': 'Unrelate {recordName}'
  },
  prompt: {
    'id': 'confirmRecordUnrelateModal.prompt',
    'defaultMessage': 'Unrelate {title} from the primary record?'
  },
  promptMultiple: {
    'id': 'confirmRecordUnrelateModal.promptMultiple',
    'defaultMessage': 'Unrelate {recordCount, plural, one {the selected record} other {# selected records}} from the primary record?'
  },
  unrelating: {
    'id': 'confirmRecordUnrelateModal.unrelating',
    'defaultMessage': 'Unrelating...'
  }
});

const propTypes = {
  config: _propTypes2.default.object,
  data: _propTypes2.default.instanceOf(_immutable2.default.Map),
  isOpen: _propTypes2.default.bool,
  isMultiSelect: _propTypes2.default.bool,
  isUnrelating: _propTypes2.default.bool,
  recordCount: _propTypes2.default.number,
  recordType: _propTypes2.default.string,
  onCancelButtonClick: _propTypes2.default.func,
  onCloseButtonClick: _propTypes2.default.func,
  onUnrelateButtonClick: _propTypes2.default.func
};

const contextTypes = {
  intl: _reactIntl.intlShape
};

class ConfirmRecordUnrelateModal extends _react.Component {
  constructor(props) {
    super(props);

    this.renderButtonBar = this.renderButtonBar.bind(this);
  }

  renderButtonBar() {
    var _props = this.props;
    const isUnrelating = _props.isUnrelating,
          onCancelButtonClick = _props.onCancelButtonClick,
          onUnrelateButtonClick = _props.onUnrelateButtonClick;


    return _react2.default.createElement(
      'div',
      null,
      _react2.default.createElement(_CancelButton2.default, {
        disabled: isUnrelating,
        onClick: onCancelButtonClick
      }),
      _react2.default.createElement(_UnrelateButton2.default, {
        isUnrelating: isUnrelating,
        onClick: onUnrelateButtonClick
      })
    );
  }

  render() {
    var _props2 = this.props;
    const config = _props2.config,
          data = _props2.data,
          isMultiSelect = _props2.isMultiSelect,
          isOpen = _props2.isOpen,
          isUnrelating = _props2.isUnrelating,
          recordCount = _props2.recordCount,
          recordType = _props2.recordType,
          onCloseButtonClick = _props2.onCloseButtonClick;


    if (!isOpen || !isMultiSelect && !data || isMultiSelect && !recordCount) {
      return null;
    }

    const intl = this.context.intl;


    const recordTypeConfig = config.recordTypes[recordType];
    const recordNameMessage = isMultiSelect ? 'collectionName' : 'name';
    const recordName = intl.formatMessage(recordTypeConfig.messages.record[recordNameMessage]);

    let content;

    if (isUnrelating) {
      content = _react2.default.createElement(_reactIntl.FormattedMessage, messages.unrelating);
    } else if (isMultiSelect) {
      content = _react2.default.createElement(_reactIntl.FormattedMessage, _extends({}, messages.promptMultiple, { values: { recordCount } }));
    } else {
      const title = recordTypeConfig.title(data, { config, intl });

      content = _react2.default.createElement(_reactIntl.FormattedMessage, _extends({}, messages.prompt, { values: { title } }));
    }

    return _react2.default.createElement(
      _cspaceLayout.Modal,
      {
        className: _ConfirmRecordUnrelateModal2.default.common,
        isOpen: isOpen,
        title: _react2.default.createElement(
          'h1',
          null,
          _react2.default.createElement(_reactIntl.FormattedMessage, _extends({}, messages.title, { values: { recordName } }))
        ),
        closeButtonClassName: 'material-icons',
        closeButtonLabel: 'close',
        renderButtonBar: this.renderButtonBar,
        onCloseButtonClick: onCloseButtonClick
      },
      content
    );
  }
}

exports.default = ConfirmRecordUnrelateModal;
ConfirmRecordUnrelateModal.modalName = 'ConfirmRecordUnrelateModal';
ConfirmRecordUnrelateModal.propTypes = propTypes;
ConfirmRecordUnrelateModal.contextTypes = contextTypes;