'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.refNameToUrl = exports.getVocabulary = exports.getRecordType = exports.refNameToCsid = undefined;

var _cspaceRefname = require('cspace-refname');

var _configHelpers = require('./configHelpers');

const refNameToCsid = exports.refNameToCsid = refName => {
  if (!refName) {
    return null;
  }

  const itemShortID = (0, _cspaceRefname.getItemShortID)(refName);

  if (itemShortID) {
    return `urn:cspace:name(${itemShortID})`;
  }

  const csid = (0, _cspaceRefname.getCsid)(refName);

  return csid || null;
};

const getRecordType = exports.getRecordType = (config, refName) => {
  if (!refName) {
    return null;
  }

  const servicePath = (0, _cspaceRefname.getServicePath)(refName);
  const recordTypeConfig = (0, _configHelpers.getRecordTypeConfigByServicePath)(config, servicePath);

  return recordTypeConfig ? recordTypeConfig.name : null;
};

const getVocabulary = exports.getVocabulary = (config, refName) => {
  if (!refName) {
    return null;
  }

  const servicePath = (0, _cspaceRefname.getServicePath)(refName);
  const recordTypeConfig = (0, _configHelpers.getRecordTypeConfigByServicePath)(config, servicePath);

  const vocabularyShortID = (0, _cspaceRefname.getVocabularyShortID)(refName);
  const vocabularyConfig = (0, _configHelpers.getVocabularyConfigByShortID)(recordTypeConfig, vocabularyShortID);

  return vocabularyConfig ? vocabularyConfig.name : null;
};

const refNameToUrl = exports.refNameToUrl = (config, refName) => {
  if (!refName) {
    return null;
  }

  const servicePath = (0, _cspaceRefname.getServicePath)(refName);
  const recordTypeConfig = (0, _configHelpers.getRecordTypeConfigByServicePath)(config, servicePath);

  if (!recordTypeConfig) {
    return null;
  }

  const recordType = recordTypeConfig.name;

  if (recordTypeConfig.vocabularies) {
    const vocabularyShortID = (0, _cspaceRefname.getVocabularyShortID)(refName);
    const vocabularyConfig = (0, _configHelpers.getVocabularyConfigByShortID)(recordTypeConfig, vocabularyShortID);

    if (!vocabularyConfig) {
      return null;
    }

    const vocabulary = vocabularyConfig.name;

    const itemShortID = (0, _cspaceRefname.getItemShortID)(refName);
    const csid = `urn:cspace:name(${itemShortID})`;

    return `/record/${recordType}/${vocabulary}/${csid}`;
  }

  const csid = (0, _cspaceRefname.getCsid)(refName);

  return `/record/${recordType}/${csid}`;
};